@@ -9,7 +9,6 @@ from uuid import uuid4
 
 import pkg_resources
 
-from django.conf import settings
 from django.template.loader import get_template
 from django.utils.translation import ugettext_lazy
 
@@ -81,14 +80,11 @@ class StudioMixin:
             self.STUDIO_EDITING_TEMPLATE
         ).render(self.editor_context())
         fragment = Fragment(rendered_template)
-        if settings.DEBUG:
-            self.add_javascript_files(fragment, "static/js/src/oa_shared.js")
-            self.add_javascript_files(fragment, "static/js/src/oa_server.js")
-            self.add_javascript_files(fragment, "static/js/src/studio")
-        else:
-            # TODO: switch to add_javascript_url once XBlock resources are loaded from the CDN
-            js_bytes = pkg_resources.resource_string(__name__, "static/js/openassessment-studio.min.js")
-            fragment.add_javascript(js_bytes.decode('utf-8'))
+
+        # TODO: switch to add_javascript_url once XBlock resources are loaded from the CDN
+        js_bytes = pkg_resources.resource_string(__name__, "static/js/openassessment-studio.js")
+        fragment.add_javascript(js_bytes.decode('utf-8'))
+
         js_context_dict = {
             "ALLOWED_IMAGE_EXTENSIONS": self.ALLOWED_IMAGE_EXTENSIONS,
             "ALLOWED_FILE_EXTENSIONS": self.ALLOWED_FILE_EXTENSIONS,
@@ -158,6 +154,7 @@ class StudioMixin:
             'file_upload_response': self.file_upload_response if self.file_upload_response else '',
             'necessity_options': self.NECESSITY_OPTIONS,
             'file_upload_type': self.file_upload_type,
+            'allow_multiple_files': self.allow_multiple_files,
             'white_listed_file_types': white_listed_file_types_string,
             'allow_latex': self.allow_latex,
             'leaderboard_show': self.leaderboard_show,
@@ -264,6 +261,7 @@ class StudioMixin:
         else:
             self.file_upload_type = None
             self.white_listed_file_types_string = None
+        self.allow_multiple_files = bool(data['allow_multiple_files'])
         self.allow_latex = bool(data['allow_latex'])
         self.leaderboard_show = data['leaderboard_show']
         self.teams_enabled = bool(data.get('teams_enabled', False))
